::: odmantic.model._BaseODMModel
    selection:
        members:
          - parse_doc
          - doc
          - update
          - copy
          - dict

::: odmantic.model.Model
    selection:
        members:
          -
::: odmantic.model.EmbeddedModel
    selection:
        members:
          -
